Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactBootstrap = require('react-bootstrap');

var _reduxModal = require('redux-modal');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * A `react-bootstrap` `Modal` component which wraps a component
 * This component is placed inside {@link ModalWrapper} so that it
 * can be connected to the `redux` state
 * @param {any} props React props
 * * `handleHide` - function to handle hiding the modal dialog
 * * `title` - Title which gets displayed in the modal dialog
 * * `show` - flag to indicate if the modal is showing or not
 * * `component` - Component to be wrapped in the modal
 * @return {React.ComponentClass} React component which contains
 * the modal and the wrapped component
 */
var InnerModal = function InnerModal(_ref) {
  var title = _ref.title,
      show = _ref.show,
      close = _ref.close,
      Component = _ref.component,
      backdrop = _ref.backdrop,
      bsSize = _ref.bsSize,
      props = _objectWithoutProperties(_ref, ['title', 'show', 'close', 'component', 'backdrop', 'bsSize']);

  return _react2['default'].createElement(
    _reactBootstrap.Modal,
    {
      backdrop: backdrop,
      bsSize: bsSize,
      show: show,
      onHide: props.handleHide
    },
    _react2['default'].createElement(
      _reactBootstrap.Modal.Header,
      { closeButton: close },
      _react2['default'].createElement(
        _reactBootstrap.Modal.Title,
        null,
        title
      )
    ),
    _react2['default'].createElement(
      _reactBootstrap.Modal.Body,
      null,
      _react2['default'].createElement(Component, props)
    )
  );
};

InnerModal.propTypes = {
  handleHide: _propTypes2['default'].func.isRequired,
  show: _propTypes2['default'].bool.isRequired,
  close: _propTypes2['default'].bool,
  component: _propTypes2['default'].element.isRequired,
  title: _propTypes2['default'].string,
  backdrop: _propTypes2['default'].oneOfType([_propTypes2['default'].oneOf(['static']), _propTypes2['default'].bool]),
  bsSize: _propTypes2['default'].oneOf(['lg', 'sm', 'small', 'large'])
};

InnerModal.defaultProps = {
  title: '',
  close: true,
  backdrop: null,
  bsSize: null
};

var PropertyInjector = function PropertyInjector(component) {
  return function (props) {
    return InnerModal(Object.assign({ component: component }, props));
  };
};

/**
 * A wrapper component for the modal dialog
 * This component connects the modal dialog to the redux state
 * @param {any} props React props
 * * `component` - The component to be wrapped by the modal
 * * `title` - A title string to pass down to the modal
 * * `name` - The name of the dialog. This field translates to field under the
 * `modal` state
 * * `destroyOnHide` - flag to indicate whether the component gets destroyed
 * when the modal closes or not
 * * `options` A set of options to configure the modal
 * * `resolve` - a resolver function to resolve before the dialog is displayed
 * @return {React.ComponentClass} A react component which
 * wraps the modal dialog
 */
var ModalWrapper = function ModalWrapper(_ref2) {
  var component = _ref2.component,
      title = _ref2.title,
      options = _ref2.options,
      props = _objectWithoutProperties(_ref2, ['component', 'title', 'options']);

  var delegateOptions = Object.keys(options).reduce(function (acc, curr) {
    /* eslint-disable no-param-reassign */
    if (!acc) acc = {};
    /* eslint-enable */
    if (options[curr] !== null) acc[curr] = options[curr];
    return acc;
  }, {});

  var ModalWithProps = PropertyInjector(component);
  var WrappedModal = (0, _reduxModal.connectModal)(Object.assign({ title: title, delegateOptions: delegateOptions }, props))(ModalWithProps);

  return _react2['default'].createElement(WrappedModal, null);
};

ModalWrapper.propTypes = {
  name: _propTypes2['default'].string.isRequired,
  title: _propTypes2['default'].string,
  resolve: _propTypes2['default'].func,
  destroyOnHide: _propTypes2['default'].bool,
  component: _propTypes2['default'].element.isRequired,
  options: _propTypes2['default'].shape({
    close: _propTypes2['default'].bool,
    backdrop: _propTypes2['default'].oneOfType([_propTypes2['default'].oneOf(['static']), _propTypes2['default'].bool]),
    bsSize: _propTypes2['default'].oneOf(['lg', 'sm', 'small', 'large'])
  })
};

ModalWrapper.defaultProps = {
  destroyOnHide: false,
  resolve: function () {
    function resolve() {
      return null;
    }

    return resolve;
  }(),
  title: '',
  options: {
    close: true,
    backdrop: null,
    bsSize: null
  }
};

exports['default'] = ModalWrapper;